Package: Rdistance
Type: Package
Title: Density and Abundance from Distance-Sampling Surveys
Version: 4.4.3
Date: 2026-05-13
Language: en-US
Maintainer: Trent McDonald <trent@mcdonalddatasciences.com>
Authors@R: c(person("Trent", "McDonald", role=c("cre","aut"), email="trent@mcdonalddatasciences.com"), 
  person("Jason", "Carlisle", role="aut", email="jason.carlisle@wyo.gov"), 
  person("Aidan", "McDonald", role="aut", email="aidan@mcdcentral.org", comment="point transect methods"), 
  person("Ryan", "Nielson", role="ctb", comment="smoothed likelihood"), 
  person("Ben", "Augustine", role="ctb", comment="maximization method"), 
  person("James", "Griswald", role="ctb", comment="maximization method"), 
  person("Patrick", "McKann", role="ctb", comment="maximization method"), 
  person("Lacey", "Jeroue", role="ctb", comment="vignettes"), 
  person("Hoffman", "Abigail", role="ctb", comment="vignettes"), 
  person("Kleinsausser", "Michael", role="ctb", comment="vignettes"),
  person("Joel", "Reynolds", role="ctb", comment="Gamma likelihood"), 
  person("Pham", "Quang", role="ctb", comment="Gamma likelihood"), 
  person("Earl", "Becker", role="ctb", comment="Gamma likelihood"), 
  person("Aaron", "Christ", role="ctb", comment="Gamma likelihood"), 
  person("Brook", "Russelland", role="ctb", comment="Gamma likelihood"), 
  person("Stefan", "Emmons", role="ctb", comment="Automated tests"),
  person("Will", "McDonald", role="ctb", comment="Automated tests"),
  person("Reid", "Olson", role="ctb", comment="Automated tests and bug fixes"))
Description: Distance-sampling (<doi:10.1007/978-3-319-19219-2>) 
  is a field survey and analytical method that estimates density and 
  abundance of survey targets (e.g., animals) when 
  detection probability declines with observation distance. 
  Distance-sampling is popular in ecology, 
  especially when survey targets are observed from aerial platforms (e.g., 
  airplane or drone), surface vessels (e.g., boat or truck), or along 
  walking transects. Analysis involves fitting smooth (parametric) curves to 
  histograms of observation distances and using those functions to 
  adjust density estimates for missed targets.  Routines included here 
  fit curves to observation distance histograms, estimate effective 
  sampling area, density of targets in surveyed areas, and the abundance 
  of targets in a surrounding study area. Confidence interval estimation
  uses built-in bootstrap resampling. Help files are extensive and have been 
  vetted by multiple authors. Many tutorials are available on the package's 
  website (URL below).
License: GNU General Public License
URL: https://mcdonalddatasciences.com/Rdistance.html
BugReports: https://github.com/tmcd82070/Rdistance/issues
LazyData: TRUE
Suggests: testthat (>= 3.0.0),
Depends: R (>= 4.1.0), units
Imports: graphics, stats, utils, crayon, withr, tidyr, dplyr, progress,
        tibble, tidyselect, dfoptim, expint, multidplyr
RoxygenNote: 7.3.3
Encoding: UTF-8
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-05-13 23:26:52 UTC; trent
Author: Trent McDonald [cre, aut],
  Jason Carlisle [aut],
  Aidan McDonald [aut] (point transect methods),
  Ryan Nielson [ctb] (smoothed likelihood),
  Ben Augustine [ctb] (maximization method),
  James Griswald [ctb] (maximization method),
  Patrick McKann [ctb] (maximization method),
  Lacey Jeroue [ctb] (vignettes),
  Hoffman Abigail [ctb] (vignettes),
  Kleinsausser Michael [ctb] (vignettes),
  Joel Reynolds [ctb] (Gamma likelihood),
  Pham Quang [ctb] (Gamma likelihood),
  Earl Becker [ctb] (Gamma likelihood),
  Aaron Christ [ctb] (Gamma likelihood),
  Brook Russelland [ctb] (Gamma likelihood),
  Stefan Emmons [ctb] (Automated tests),
  Will McDonald [ctb] (Automated tests),
  Reid Olson [ctb] (Automated tests and bug fixes)
Repository: CRAN
Date/Publication: 2026-05-14 13:50:18 UTC
Built: R 4.6.0; ; 2026-05-14 15:50:36 UTC; unix
