# Generated by roxygen2: do not edit by hand

S3method(AIC,dfunc)
S3method(coef,dfunc)
S3method(lines,dfunc)
S3method(model.matrix,dfunc)
S3method(plot,dfunc)
S3method(predict,dfunc)
S3method(print,abund)
S3method(print,dfunc)
S3method(summary,abund)
S3method(summary,dfunc)
S3method(summary,rowwise_df)
export("%#%")
export(EDR)
export(ESW)
export(Gamma.like)
export(Gamma.start.limits)
export(GammaModes)
export(GammaReparam)
export(RdistDf)
export(abundEstim)
export(autoDistSamp)
export(bcCI)
export(bootstrap)
export(bspline.expansion)
export(checkUnits)
export(cosine.expansion)
export(dE.multi)
export(dE.single)
export(dfuncEstim)
export(differentiableLikelihoods)
export(distances)
export(dropUnits)
export(effectiveDistance)
export(effort)
export(estimateN)
export(expandW)
export(expansionTerms)
export(groupSizes)
export(gxEstim)
export(halfnorm.like)
export(halfnorm.start.limits)
export(hazrate.like)
export(hazrate.start.limits)
export(hermite.expansion)
export(huber.cumFunc)
export(huber.like)
export(huber.start.limits)
export(integrateDfuncs)
export(integrateGammaLines)
export(integrateHalfnormLines)
export(integrateHalfnormPoints)
export(integrateHazrateLines)
export(integrateHuberLines)
export(integrateNegexpLines)
export(integrateNegexpPoints)
export(integrateNumeric)
export(integrateOneStepLines)
export(integrateOneStepNumeric)
export(integrateOneStepPoints)
export(integrateTriangleLines)
export(is.RdistDf)
export(is.Unitless)
export(is.points)
export(is.smoothed)
export(likeParamNames)
export(maximize.g)
export(mlEstimates)
export(nLL)
export(negexp.like)
export(negexp.start.limits)
export(observationType)
export(oneBsIter)
export(oneStep.like)
export(oneStep.start.limits)
export(parseModel)
export(perpDists)
export(predDensity)
export(predDfuncs)
export(predLikelihood)
export(secondDeriv)
export(setOptimizer)
export(setUnits)
export(simple.expansion)
export(simpsonCoefs)
export(sine.expansion)
export(startLimits)
export(transectType)
export(triangle.like)
export(triangle.start.limits)
export(unnest)
export(varcovarEstim)
exportPattern(`%.+%`)
import(units)
